@@ -3,7 +3,6 @@
 use warnings;
 use strict;
 use Gtk2 -init;
-use MyObject;
 use Gtk2::GladeXML;
 use Gtk2::GladeXML::OO;
 #======================================================================
@@ -22,3 +21,22 @@ sub gtk_main_quit { Gtk2->main_quit; }
 #######################################################################
 
 Gtk2->main;
+
+#======================================================================
+#						MyObject
+#======================================================================
+# Here or in separate file... 
+{
+package MyObject;
+
+our $VERSION = '0.01';
+
+sub new {
+	return bless \$_[0], $_[0]; 
+}
+
+sub set_it { 
+	print "I was clicked!\n"; 
+}
+}
+#======================================================================
